cd "C:\kill_CScore\sim\"
//do prepdata_crsp
do prepdata_comp

tabstat Earn R LSize LBM LLev, stats(mean sd p25 p50 p75 count) columns(s)

// use pooled extended Basu model w/ Khan-Watts controls as the "true" coefficients 
reg Earn (c.D c.R c.D_R)##(c.LSize c.LBM c.LLev), cluster(gvkeyN)
predict PRED_EARN, xb  // this will be the baseline for simulated Earn
sca SD_EPS=e(rmse)

// define X for the simulation scenario
sca PROP_NORMAL = 0.0
gen baseX = LBM*(fyear-1962) //  // (fyear-1962) //
qui sum baseX
replace baseX = (baseX-`r(mean)')/`r(sd)'


// prep vars for quick estimation of Basu with firm- and year-specific coefficients
gen simEarn=.
gen X=.
tab fyear, gen(yr)
foreach v1 of varlist D R D_R{
	foreach v2 of varlist yr* LSize LBM LLev X{
		gen `v1'_`v2'=`v1'*`v2'
	}
}

// for the pooled controls, I can do the aux regression once outside the simulation loop
local pooledControls = "yr* LSize LBM LLev D_yr* R_yr* D_R_yr* D_L* R_L* D_R_L*"
local simSpecificVars = "simEarn X D_X R_X D_R_X"
foreach var of varlist `pooledControls' `simSpecificVars'{
	gen r_`var'=.  
}

foreach var of varlist `pooledControls'{
	dis "VAR = `var'"
	rangestat (reg) `var' D R D_R, by(gvkeyN) interval(fyear . .)	
	replace r_`var'=`var' - b_cons - D*b_D - R*b_R - D_R*b_D_R
	drop reg_nobs- se_cons
}


postfile Results2 b_Basu se_Basu b_BasuFE se_BasuFE using Results2, replace
forval sim = 1/2{ // 250
	dis `sim'
	local seedNo = 666 + `sim'  
	set seed `seedNo'		   
	
	qui replace X = sqrt(PROP_NORMAL)*rnormal() + sqrt(1-PROP_NORMAL)*baseX
	foreach var of varlist R D D_R{
		qui replace `var'_X = `var'*X
	}
	
	qui replace simEarn = PRED_EARN + 1.0*D_R*X + rnormal()*SD_EPS
	
	// standard Basu model estimates with relevant interactions
	qui reg simEarn (c.D c.R c.D_R)##(c.LSize c.LBM c.LLev c.X), cluster(gvkeyN)
	sca b_Basu = _b[c.D_R#c.X]
	sca se_Basu = _se[c.D_R#c.X]
	
	// partialled-out Basu with firm-specific slopes
	foreach var of varlist `simSpecificVars'{
		rangestat (reg) `var' D R D_R, by(gvkeyN) interval(fyear . .)	
		qui replace r_`var'=`var' - b_cons - D*b_D - R*b_R - D_R*b_D_R
		drop reg_nobs- se_cons
	}

	qui reg r_simEarn r_yr* r_L* r_D_yr* r_D_L*  r_R_yr* r_R_L*  r_D_R_yr* r_D_R_L*  ///
										r_X r_D_X r_R_X r_D_R_X, cluster(gvkeyN) nocons
	sca b_BasuFE = _b[r_D_R_X]
	sca se_BasuFE = _se[r_D_R_X]
	
	post Results2 (b_Basu) (se_Basu) (b_BasuFE) (se_BasuFE)
}
postclose Results2

end

use Results2, clear
foreach est in "Basu" "BasuFE"{  
	gen diff0_`est' = ( abs(b_`est'/se_`est')>1.96 )      // =1 if significantly differs from zero
	gen diff1_`est' = ( abs( (b_`est'-1)/se_`est')>1.96 ) // =1 if significantly differs from true value
}

tabstat b_*, stats(mean sd) columns(s) format(%6.4f)
tabstat diff*, stats(mean) columns(s) varwidth(15) format(%4.3f)
