cd "C:\kill_CScore\sim\"
//do prepdata_crsp
do prepdata_comp

tabstat Earn R LSize LBM LLev, stats(mean sd p25 p50 p75 count) columns(s)

// use pooled extended Basu model w/ Khan-Watts controls as the "true" coefficients 
reg Earn (c.D c.R c.D_R)##(c.LSize c.LBM c.LLev), cluster(gvkeyN)
predict PRED_EARN, xb  // this will be the baseline for simulated Earn
sca SD_EPS=e(rmse)

// define X for the simulation scenario
sca PROP_NORMAL = 0.5 // 0.5 
gen baseX = LBM*(fyear-1962) //(fyear-1962)  // LBM*(fyear-1962)
qui sum baseX
replace baseX = (baseX-`r(mean)')/`r(sd)'

postfile Results b_Basu se_Basu b_CScore se_CScore b_CScoreFE se_CScoreFE using Results, replace
forval sim = 1/250{
	dis `sim'
	local seedNo = 666 + `sim'  
	set seed `seedNo'		   
	
	// uncomment the relevant scenario
	qui gen X = sqrt(PROP_NORMAL)*rnormal() + sqrt(1-PROP_NORMAL)*baseX
	
	qui gen simEarn = PRED_EARN + 1.0*D_R*X + rnormal()*SD_EPS
	
	// standard Basu model estimates with relevant interactions
	qui reg simEarn (c.D c.R c.D_R)##(c.LSize c.LBM c.LLev c.X), cluster(gvkey)
	sca b_Basu = _b[c.D_R#c.X]
	sca se_Basu = _se[c.D_R#c.X]
	
	// estimate Khan-Watts CScore using annual cross-sectional regressions in simulated data
	qui gen CScore=.
	qui sum fyear
	forval yr = `r(min)'/`r(max)'{ 
		qui reg simEarn (c.D c.R c.D_R)##(c.LSize c.LBM c.LLev) if fyear==`yr'
		qui replace CScore = _b[c.D_R] + _b[c.D_R#c.LSize]*LSize + _b[c.D_R#c.LBM]*LBM + _b[c.D_R#c.LLev]*LLev if fyear==`yr'
	}

	// basic stage 2 for CScore
	qui reg CScore LSize LBM LLev X, cluster(gvkey) 
	sca b_CScore = _b[X]	
	sca se_CScore = _se[X]	
	
	// extended stage 2 for CScore with year and firm FE
	qui xtreg CScore LSize LBM LLev X i.fyear, fe cluster(gvkey) 	
	sca b_CScoreFE = _b[X]
	sca se_CScoreFE = _se[X]	
	
	drop X simEarn CScore
	
	post Results (b_Basu) (se_Basu) (b_CScore) (se_CScore) (b_CScoreFE) (se_CScoreFE)
}
postclose Results

use Results, clear
foreach est in "Basu" "CScore" "CScoreFE"{  
	gen diff0_`est' = ( abs(b_`est'/se_`est')>1.96 )      // =1 if significantly differs from zero
	gen diff1_`est' = ( abs( (b_`est'-1)/se_`est')>1.96 ) // =1 if significantly differs from true value
}

tabstat b_*, stats(mean sd) columns(s) format(%6.4f)
tabstat diff*, stats(mean) columns(s) varwidth(15) format(%4.3f)
