clear all
cd "C:\kill_Cscore\simFscore\"
do prep_data

// predicted linear score from Dechow et al. (2011) model 1 in Table 7
gen BASE_LOGIT_SCORE = -7.893 + 0.790*RSST_ACC + 2.518*dRECT + 1.191*dINV + 1.979*propSOFT + 0.171*dCSALE + (-0.932)*dROA + 1.029*ISSUE

local STAGE2_VARS = "RSST_ACC dRECT dINV propSOFT dCSALE dROA ISSUE X" // exclude at least one variable from the FScore list

gen X = .
gen simAAER = .
gen trueLogitScore = .
gen truePr = .

gen BASE_X = propSOFT^2 //propSOFT/0.2502-RSST_ACC/0.2519 // propSOFT  // the var with the largest standardized coeff  in FScore
sum BASE_X
replace BASE_X = (BASE_X - `r(mean)')/(`r(sd)'+1e-6)
sum BASE_X

sca trueDeltaX = 0*1


postfile Results b_correct se_correct b_correctFE se_correctFE b_FScore se_FScore b_FScoreFE se_FScoreFE  b_FScore2 se_FScore2 b_FScoreFE2 se_FScoreFE2  using Results, replace
forval sim=1/250{
	qui replace X = sqrt(0.5)*rnormal(0,1) + sqrt(0.5)*BASE_X
	dis `sim'
	local seedNo = 666 + `sim'  
	set seed `seedNo'		   
	
	qui replace trueLogitScore = BASE_LOGIT_SCORE + trueDeltaX*X
	qui replace truePr = exp(trueLogitScore)/(1+exp(trueLogitScore))
	
	qui replace simAAER = (runiform()<truePr)
	
	// correct single-stage logit estimates
	quietly eststo, title("correct"): logit simAAER RSST_ACC dRECT dINV propSOFT dCSALE dROA ISSUE X, cluster(gvkeyN)
	sca b_correct = _b[X]
	sca se_correct = _se[X]
	
	quietly eststo, title("correctFE"): clogit simAAER RSST_ACC dRECT dINV propSOFT dCSALE dROA ISSUE X i.fyear, group(gvkeyN) cluster(gvkeyN)
	sca b_correctFE = _b[X]
	sca se_correctFE = _se[X]
	
	// update FScore estimates -- cannot just reuse published coefficients b/c shd reflect the true relation with X
	quietly eststo, title("stage 1"): logit simAAER RSST_ACC dRECT dINV propSOFT dCSALE dROA ISSUE, cluster(gvkeyN)
	predict FScore, pr  // strictly speaking, should be scaled by uncond prob, but it does not matter
	qui sum FScore, meanonly
	replace FScore = FScore/`r(mean)'
	
	quietly eststo, title("stage 2"): reg FScore `STAGE2_VARS', cluster(gvkeyN)
	sca b_FScore = _b[X]
	sca se_FScore = _se[X]

	quietly eststo, title("stage 2 w/o W"): reg FScore X, cluster(gvkeyN)
	sca b_FScore2 = _b[X]
	sca se_FScore2 = _se[X]

	quietly eststo, title("stage 2FE"): xtreg FScore `STAGE2_VARS' i.fyear, fe cluster(gvkeyN)
	sca b_FScoreFE = _b[X]
	sca se_FScoreFE = _se[X]

	quietly eststo, title("stage 2FE w/o W"): xtreg FScore X i.fyear, fe cluster(gvkeyN)
	sca b_FScoreFE2 = _b[X]
	sca se_FScoreFE2 = _se[X]

	
	esttab, b(%8.3f) ar2 star(* 0.10 ** 0.05 *** 0.01) mtitles nonumbers not order(_cons) // keep(X)
	eststo clear
	
	post Results (b_correct) (se_correct) (b_correctFE) (se_correctFE) (b_FScore) (se_FScore) (b_FScoreFE) (se_FScoreFE) (b_FScore2) (se_FScore2) (b_FScoreFE2) (se_FScoreFE2) 
	drop FScore
}

postclose Results

use Results, clear
foreach est in "correct" "correctFE" "FScore" "FScoreFE" "FScore2" "FScoreFE2"{  
	gen diff0_`est' = ( abs(b_`est'/se_`est')>1.96 )      // =1 if significantly differs from zero
	gen diff1_`est' = ( abs( (b_`est'-1)/se_`est')>1.96 ) // =1 if significantly differs from true value
}

tabstat b_*, stats(mean sd) columns(s) format(%6.4f)
tabstat diff*, stats(mean) columns(s) varwidth(15) format(%4.3f)
